module Roqua
  module RomApi
    # @example To create a fill out request run:
    #   Roqua::RomApi::CreateFillOutRequest.run! \
    #     dossier_id: dossier_id,
    #     questionnaire_keys: ['key1', 'key2'],
    #     callback_url: notify_callback_path(token: 'secret')
    #
    # @see http://docs.roqua.net/developer/rom/dossier/fill_out_requests/ for more info on how callbacks work.
    class CreateFillOutRequest < Endpoint
      string    :dossier_id
      integer   :measurement_sequence_id, default: nil
      array     :questionnaire_keys, default: [] do string end
      string    :respondent_type, default: nil
      string    :callback_url, default: nil
      array     :reminders, default: []
      time      :open_from, default: nil, allow_nil: true
      time      :open_till, default: nil, allow_nil: true

      validates :dossier_id, presence: {allow_blank: false}

      private

      def execute
        validate_response_for do
          fill_out_request = {
            measurement_sequence_id: measurement_sequence_id,
            questionnaire_keys: questionnaire_keys,
            respondent_type: respondent_type,
            callback_url: callback_url,
            reminders: reminders,
            open_from: open_from && open_from.to_i,
            open_till: open_till && open_till.to_i
          }.keep_if { |_k, v| v.present? }
          basic_auth_session.post("/dossiers/#{dossier_id}/fill_out_requests",
                                  fill_out_request: fill_out_request)
        end
      end

      def response_to_result(response)
        Models::FillOutRequest.new(response)
      end
    end
  end
end
