module Roqua
  module RomApi
    # @api private
    class ListResponses < Endpoint
      string :dossier_id
      array  :response_ids,             default: [] do string end
      array  :questionnaire_keys,       default: [] do string end
      time   :completed_before,         default: nil
      time   :completed_after,          default: nil
      string :respondent_type,          default: nil
      symbol :status,                   default: nil
      string :protocol_subscription_id, default: nil

      def execute
        validate_response_for do
          basic_auth_session.get "/dossiers/#{dossier_id}/responses", filter_params
        end
      end

      def filter_params
        {
          response_ids: response_ids,
          respondent_type: respondent_type,
          status: status,
          questionnaire_keys: questionnaire_keys,
          completed_after: completed_after,
          completed_before: completed_before,
          protocol_subscription_id: protocol_subscription_id
        }.keep_if { |_k, v| v.present? }
      end

      def response_to_result(response)
        response.map { |r| Models::Response.new(r) }
      end
    end
  end
end
