module Roqua
  module RomApi
    # @api private
    class ReportCalculations < Endpoint
      string :dossier_id
      string :calculator
      array :response_ids, default: nil do string end
      array :questionnaire_keys, default: nil do string end
      time :completed_after, default: nil
      time :completed_before, default: nil

      validates :questionnaire_keys, presence: true, unless: -> { response_ids.present? }

      def execute
        validate_response_for do
          basic_auth_session.get "/dossiers/#{dossier_id}/report_calculations", params
        end
      end

      private

      def params
        {calculator: calculator}.merge(filter_params)
      end

      def filter_params
        if response_ids.present?
          {response_ids: response_ids}
        else
          {filters: {
            questionnaire_keys: questionnaire_keys,
            completed_after: completed_after && completed_after.to_i,
            completed_before: completed_before && completed_before.to_i
          }}.keep_if { |_k, v| v.present? }
        end
      end
    end
  end
end
